@@ -1,7 +1,7 @@
 use strictures;
 
 package WebService::GoogleAPI::Client;
-$WebService::GoogleAPI::Client::VERSION = '0.10';
+$WebService::GoogleAPI::Client::VERSION = '0.11';
 
 # ABSTRACT: Google API Services Client.
 
@@ -37,12 +37,16 @@ has 'discovery' => (
 
 ## provides a way of augmenting constructor (new) without overloading it
 ##  see https://metacpan.org/pod/distribution/Moose/lib/Moose/Manual/Construction.pod if like me you an new to Moose
+
+
 sub BUILD
 {
   my ( $self, $params ) = @_;
 
   $self->auth_storage->setup( { type => 'jsonfile', path => $params->{ gapi_json } } ) if ( defined $params->{ gapi_json } );
   $self->user( $params->{ user } ) if ( defined $params->{ user } );
+
+  ## how to handle chi as a parameter
   $self->discovery->chi( $self->chi );    ## is this redundant? set in default?
 
 
@@ -95,6 +99,8 @@ sub api_query
   ## pre-query validation if api_id parameter is included
   ## push any critical issues onto @teapot_errors
   ## include interpolation and defaults if required because user has ommitted them
+
+
   if ( defined $params->{ api_endpoint_id } )
   {
 
@@ -112,7 +118,12 @@ sub api_query
       ## set http method to default if unset
       if ( not defined $params->{ method } )
       {
-        $params->{ method } = $method_discovery_struct->{ httpMethod } || croak( "API Endpoint discovered specification didn't include expected httpMethod value" );
+        $params->{ method } = $method_discovery_struct->{ httpMethod } || carp( "API Endpoint discovered specification didn't include expected httpMethod value" );
+        if ( not defined $params->{ method } )       ##
+        {
+          carp( 'setting to GET but this may well be incorrect' );
+          $params->{ method } = 'GET';
+        }
       }
       elsif ( $params->{ method } !~ /^$method_discovery_struct->{httpMethod}$/sxim )
       {
@@ -123,7 +134,9 @@ sub api_query
         unless ref( $method_discovery_struct->{ parameters } ) eq 'HASH';
 
       ## Set default path iff not set by user - NB - will prepend baseUrl later
-      $params->{ path } = "$method_discovery_struct->{path}" unless defined $params->{ path };
+      $params->{ path } = $method_discovery_struct->{ path } unless defined $params->{ path };
+      push @teapot_errors, 'path is a required parameter' unless defined $params->{ path };
+
       foreach my $meth_param_spec ( keys %{ $method_discovery_struct->{ parameters } } )
       {
         ## set default value if is not provided within $params->{options} - nb technically not required but provides visibility of the params if examining the options when debugging
@@ -137,7 +150,7 @@ sub api_query
 
         carp( "checking discovery spec'd parameter - $meth_param_spec" ) if $self->debug > 10;
 
-#carp("$meth_param_spec  has a user option value defined") if ( defined $params->{options}{$meth_param_spec} );
+        #carp("$meth_param_spec  has a user option value defined") if ( defined $params->{options}{$meth_param_spec} );
         if ( $params->{ path } =~ /\{.+\}/xms )    ## there are un-interpolated variables in the path - try to fill them for this param if reqd
         {
           carp( "$params->{path} includes unfilled variables " ) if $self->debug > 10;
@@ -218,6 +231,9 @@ sub api_query
 
   }
 
+
+  push @teapot_errors, 'path is a required parameter' unless defined $params->{ path };
+
   if ( @teapot_errors > 0 )    ## carp and include in 418 response body the teapot errors
   {
     carp( join( "\n", @teapot_errors ) ) if $self->debug;
@@ -231,6 +247,7 @@ sub api_query
   else
   {
     #carp Dumper $params;
+
     return $self->ua->validated_api_query( $params );
 
 
@@ -245,10 +262,13 @@ sub api_query
 sub has_scope_to_access_api_endpoint
 {
   my ( $self, $api_ep ) = @_;
+  return 0 unless defined $api_ep;
+  return 0 if $api_ep eq '';
+  my $method_spec = $self->extract_method_discovery_detail_from_api_spec( $api_ep );
 
-  if ( keys( my $method_spec = $self->extract_method_discovery_detail_from_api_spec( $api_ep ) ) > 0 )    ## empty hash indicates failure
+  if ( keys( %$method_spec ) > 0 )    ## empty hash indicates failure
   {
-    my $configured_scopes = $self->ua->get_scopes_as_array();                                             ## get user scopes arrayref
+    my $configured_scopes = $self->ua->get_scopes_as_array();    ## get user scopes arrayref
     ## create a hashindex to facilitate quick lookups
     my %configured_scopes_hash = map { s/\/$//xr, 1 } @$configured_scopes;    ## NB r switch as per https://www.perlmonks.org/?node_id=613280 to filter out any trailing '/'
     my $granted                = 0;                                           ## assume permission not granted until we find a matching scope
@@ -288,7 +308,7 @@ WebService::GoogleAPI::Client - Google API Services Client.
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -309,10 +329,11 @@ Access Google API Services Version 1 using an OAUTH2 User Agent
 
 =head2 OAUTH CREDENTIALS FILE TO ACCESS SERVCICES
 
-While I personally find the goauth tool useful to create local auth credentials and can work with the code,
-you may find it more useful to do it all yourself using an approach like at https://blog.ludin.org/2017/01/15/using-google-apis-with-perl-part-3-simplicity/
+TODO
 
-This code still retains a lot of the bad smells of the parents. 
+=head2 BUILD
+
+WebService::GoogleAPI::Client->new( user => 'useremail@sdf.com', gapi_json => '/fullpath/gapi.json' );
 
 =head2 api_query
 
@@ -397,6 +418,8 @@ SEE ALSO:
 Returns an array list of all the available API's described in the API Discovery Resource
 that is either fetched or cached in CHI locally for 30 days.
 
+WHen called in a scalar context returns the list as a comma joined string.
+
 DELEGATED FROM WebService::GoogleAPI::Client::Discovery
 
 =head1 FUNCTIONAL CLASS PROPERTIES
@@ -466,7 +489,7 @@ requests in a way that is as portable to alternative approaches as possible.
 
 =item * L<Google Cloud Blog https://www.blog.google/products/google-cloud/>
 
-=item * L<Moo::Google> - The original code base later forked into L<WebService::Google> by Steve Dondley. This is where this code started believing that I could clean it up. In hindisght it would have been much easier to start from scratch.
+=item * L<Moo::Google> - The original code base later forked into L<WebService::Google::Client> by Steve Dondley. Some shadows of the original design remain
 
 =item * L<Google Swagger API https://github.com/APIs-guru/google-discovery-to-swagger> 
 
@@ -480,7 +503,7 @@ Peter Scott <localshop@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017-2018 by Pavel Serikov, Peter Scott and others.
+This software is Copyright (c) 2017-2018 by Peter Scott and others.
 
 This is free software, licensed under:
 
