@@ -1,7 +1,7 @@
 use strictures;
 
 package WebService::GoogleAPI::Client::UserAgent;
-$WebService::GoogleAPI::Client::UserAgent::VERSION = '0.10';
+$WebService::GoogleAPI::Client::UserAgent::VERSION = '0.11';
 
 # ABSTRACT: User Agent wrapper for working with Google APIs
 
@@ -48,13 +48,12 @@ sub header_with_bearer_auth_token
   if ( $self->access_token )
   {
     $headers->{ 'Authorization' } = 'Bearer ' . $self->access_token;
-    return $headers;
   }
   else
   {
-    croak 'No access_token, can\'t build headers';
+    carp 'No access_token, can\'t build Auth header';
   }
-
+  return $headers;
 }
 
 
@@ -62,14 +61,17 @@ sub build_http_transaction
 {
   my ( $self, $params ) = @_;
   ## hack to allow method option as alias for httpMethod
+
   $params->{ httpMethod } = $params->{ method } if defined $params->{ method };
-  my $http_method   = uc( $params->{ httpMethod } ) || 'GET';                                                           # uppercase ?
+  $params->{ httpMethod } = '' unless defined $params->{ httpMethod };
+
+  my $http_method   = uc( $params->{ httpMethod } ) || 'GET';                                                          # uppercase ?
   my $optional_data = $params->{ options }          || '';
-  my $path          = $params->{ path }             || croak( 'path parameter required for build_http_transaction' );
-  my $no_auth       = $params->{ no_auth }          || 0;                                                               ## default to including auth header - ie not setting no_auth
+  my $path          = $params->{ path }             || carp( 'path parameter required for build_http_transaction' );
+  my $no_auth       = $params->{ no_auth }          || 0;                                                              ## default to including auth header - ie not setting no_auth
   carp 'Attention! You are using POST, but no payload specified' if ( ( $http_method eq 'POST' ) && !defined $optional_data );
   carp "build_http_transaction:: $http_method $path " if $self->debug;
-  croak "$http_method Not a SUPPORTED HTTP method parameter specified to build_http_transaction" . Dumper $params unless $http_method =~ /^GET|PATH|PUT|POST|PATCH|DELETE$/ixm;
+  carp "$http_method Not a SUPPORTED HTTP method parameter specified to build_http_transaction" . Dumper $params unless $http_method =~ /^GET|PATH|PUT|POST|PATCH|DELETE$/ixm;
 
 
   my $headers = {};
@@ -107,11 +109,7 @@ sub validated_api_query
 
   if ( ( $res->code == 401 ) && $self->do_autorefresh )
   {
-    #my $attempt = 1; ## is this used? perhaps intent was to allow requery with delays on fail ?
-
-    #while ($res->{error}{message} eq 'Invalid Credentials')  {
-    #while ( $res->code == 401 ) ## won't this just continue making requests ? - replacing with if
-    if ( $res->code == 401 )
+    if ( $res->code == 401 )     ## redundant - was there something else in mind ?
     {
       croak "No user specified, so cant find refresh token and update access_token" unless $self->user;
       carp "401 response - access_token was expired. Attemptimg to update it automatically ..." if $self->debug;
@@ -183,7 +181,7 @@ WebService::GoogleAPI::Client::UserAgent - User Agent wrapper for working with G
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 METHODS
 
@@ -246,7 +244,7 @@ Peter Scott <localshop@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017-2018 by Pavel Serikov, Peter Scott and others.
+This software is Copyright (c) 2017-2018 by Peter Scott and others.
 
 This is free software, licensed under:
 
